<?php
/*
 * Tutorial: How to Disable Revisions in WordPress
 * URL: https://www.rafaelcardero.com/tutorials/how-to-disable-revisions-in-wordpress/
 */

/* -----------------------------------------------------------------------------
 * - Method 1
 * ---------------------------------------------------------------------------*/

/*
 * Registers the custom post type Book.
 */
function ns_register_book_cpt(){
    
    // See all possible labels in the PHPDoc of the function get_post_type_labels
    $labels = array(
       'name'                  => __('Books', 'ns'),
       'singular_name'         => __('Book', 'ns'),
       'menu_name'             => __('Books', 'ns'),
       'all_items'             => __('All Books', 'ns'),
       'add_new'               => __('Add New', 'ns'),
       'add_new_item'          => __('Add New Book', 'ns'),
       'edit_item'             => __('Edit Book', 'ns'),
       'new_item'              => __('New Book', 'ns'),
       'view_item'             => __('View Book', 'ns'),
       'view_items'            => __('View Books', 'ns'),
       'search_items'          => __('Search Books', 'ns'),
       'not_found'             => __('No books found.', 'ns'),
       'not_found_in_trash'    => __('No books found in Trash.', 'ns'),
       'archives'              => __('Book Archives', 'ns'),
       'filter_items_list'     => __('Filter books list', 'ns'),
       'items_list_navigation' => __('Books list navigation', 'ns'),
       'items_list'            => __('Books list', 'ns')
    );
    
    // See all possible attributes in the PHPDoc of the function register_post_type
    $args = array(
        'label'                 => __('Books', 'ns'),
        'labels'                => $labels, 
        'public'                => true,
        'exclude_from_search'   => false,
        'publicly_queryable'    => true,
        'show_ui'               => true,
        'show_in_nav_menus'     => true,
        'show_in_menu'          => true,
        'show_in_admin_bar'     => true,
        'hierarchical'          => false,
        'supports'              => array('title', 'editor', 'author'), 
        'taxonomies'            => array('post_tag'),
        'has_archive'           => true, 
        'rewrite'               => array('slug' => 'books'),
        'query_var'             => 'book'
    );
    
    register_post_type('ns_book_cpt', $args);
}
add_action('init', 'ns_register_book_cpt', 10, 0);

/* -----------------------------------------------------------------------------
 * - Method 2
 * ---------------------------------------------------------------------------*/

/*
 * Disables revisions for the post types Post and Page.
 */
function ns_disable_revisions($num, $post){
    
    $target_types = array('post', 'page');
    $is_target_type = in_array($post->post_type, $target_types);
    return $is_target_type ? 0 : $num;
}
add_filter('wp_revisions_to_keep', 'ns_disable_revisions', 10, 2);

/* -----------------------------------------------------------------------------
 * - Method 3
 * ---------------------------------------------------------------------------*/

// Disable revisions for all post types
// define('WP_POST_REVISIONS', 0); // Place this line in the file wp-config.php

/* -----------------------------------------------------------------------------
 * - Exercise
 * ---------------------------------------------------------------------------*/

/*
 * Registers the custom post type Magazine.
 */
function ns_register_magazine_cpt(){
    
    // See all possible labels in the PHPDoc of the function get_post_type_labels
    $labels = array(
       'name'                  => __('Magazines', 'ns'),
       'singular_name'         => __('Magazine', 'ns'),
       'menu_name'             => __('Magazines', 'ns'),
       'all_items'             => __('All Magazines', 'ns'),
       'add_new'               => __('Add New', 'ns'),
       'add_new_item'          => __('Add New Magazine', 'ns'),
       'edit_item'             => __('Edit Magazine', 'ns'),
       'new_item'              => __('New Magazine', 'ns'),
       'view_item'             => __('View Magazine', 'ns'),
       'view_items'            => __('View Magazines', 'ns'),
       'search_items'          => __('Search Magazines', 'ns'),
       'not_found'             => __('No magazines found.', 'ns'),
       'not_found_in_trash'    => __('No magazines found in Trash.', 'ns'),
       'archives'              => __('Magazine Archives', 'ns'),
       'filter_items_list'     => __('Filter magazines list', 'ns'),
       'items_list_navigation' => __('Magazines list navigation', 'ns'),
       'items_list'            => __('Magazines list', 'ns')
    );
    
    // See all possible attributes in the PHPDoc of the function register_post_type
    $args = array(
        'label'                 => __('Magazines', 'ns'),
        'labels'                => $labels, 
        'public'                => true,
        'exclude_from_search'   => false,
        'publicly_queryable'    => true,
        'show_ui'               => true,
        'show_in_nav_menus'     => true,
        'show_in_menu'          => true,
        'show_in_admin_bar'     => true,
        'hierarchical'          => false,
        'supports'              => array('title', 'editor', 'author', 'revisions'), 
        'taxonomies'            => array('post_tag'),
        'has_archive'           => true, 
        'rewrite'               => array('slug' => 'magazines'),
        'query_var'             => 'magazine'
    );
    
    register_post_type('ns_magazine_cpt', $args);
}
add_action('init', 'ns_register_magazine_cpt', 10, 0);

/*
 * Sets the number of revisions kept for entries of the post type Magazine.
 */
function ns_set_magazine_revisions($num, $post){
    
    return ($post->post_type == 'ns_magazine_cpt') ? 5 : $num;
}
add_filter('wp_revisions_to_keep', 'ns_set_magazine_revisions', 10, 2);